@@ -75,11 +75,123 @@ from math import lgamma, modf, nextafter, perm, prod, remainder, trunc, ulp
 
 ### CONVERSIONS ###
 ##TODO: Add more values to conversions
-_dirlist = __file__.split(_os.sep)
-_dirlist[-1] = 'Conversions.json'
-_conversions_file_name = _os.sep.join(_dirlist)
-conversions = _json.loads(open(_conversions_file_name).read())
-
+{'rad':
+  {'type': 'angle',
+   'value': 'tau'
+  },
+ 'deg':
+  {'type': 'angle',
+   'value': '360'
+  },
+ 'grad':
+  {'type': 'angle',
+   'value': '400'
+  },
+ 'meter':
+  {'type': 'length',
+   'value': 1
+  },
+ 'decameter':
+  {'type': 'length',
+   'value': 1/10
+  },
+ 'hectometer':
+  {'type': 'length',
+   'value': 1/100
+  },
+ 'kilometer':
+  {'type': 'length',
+   'value': 1/1000
+  },
+ 'megameter':
+  {'type': 'length',
+   'value': 1/1000000
+  },
+ 'gigameter':
+  {'type': 'length',
+   'value': 1/1000000000
+  },
+ 'terrameter':
+  {'type': 'length',
+   'value': 1/1000000000
+  },
+ 'petameter':
+  {'type': 'length',
+   'value': 1/1000000000000000
+  },
+ 'exameter':
+  {'type': 'length',
+   'value': 1/1000000000000000000
+  },
+ 'zettameter':
+  {'type': 'length',
+   'value': 1/1000000000000000000000
+  },
+ 'yottameter':
+  {'type': 'length',
+   'value': 1/1000000000000000000000000
+  },
+ 'decimeter':
+  {'type': 'length',
+   'value': 10
+  },
+ 'centimeter':
+  {'type': 'length',
+   'value': 100
+  },
+ 'millimeter':
+  {'type': 'length',
+   'value': 1000
+  },
+ 'micrometer':
+  {'type': 'length',
+   'value': 1000000
+  },
+ 'nanometer':
+  {'type': 'length',
+   'value': 1000000000
+  },
+ 'picometer':
+  {'type': 'length',
+   'value': 1000000000000
+  },
+ 'femtometer':
+  {'type': 'length',
+   'value': 1000000000000000
+  },
+ 'attometer':
+  {'type': 'length',
+   'value': 1000000000000000000
+  },
+ 'zeptometer':
+  {'type': 'length',
+   'value': 1000000000000000000000
+  },
+ 'yoctometer':
+  {'type': 'length',
+   'value': 1000000000000000000000000
+  },
+ 'foot':
+  {'type': 'length',
+   'value': 3.2808398949899997
+  },
+ 'inches':
+  {'type': 'length',
+   'value': 39.37007873988
+  },
+ 'yard':
+  {'type': 'length',
+   'value': 1.09361329833
+  },
+ 'mile':
+  {'type': 'length',
+   'value': 0.0006213711922329545
+  },
+ 'nautical_mile':
+  {'type': 'length',
+   'value': 0.0005399670663248847
+  }
+}
 
 
 ### checks ###
